@@ -31,7 +31,7 @@ class ChecksOdooModuleCSV:
         csvids = defaultdict(list)
         for manifest_data in self.manifest_datas:
             try:
-                with open(manifest_data["filename"], "r", encoding="UTF-8") as f_csv:
+                with open(manifest_data["filename"], encoding="UTF-8") as f_csv:
                     csv_r = csv.DictReader(f_csv)
                     if not csv_r or "id" not in csv_r.fieldnames:
                         continue
